
//
// LitFogged3D - Textured and vertex coloured
//

[VertexShader]

attribute highp   vec3 	inPos;
attribute mediump vec2 	inUV;	 
attribute lowp    vec4 	inCol;	 
attribute mediump vec3 	inNorm;

varying   mediump vec4 	outCol;
varying   lowp    vec2 	outUV;	 
uniform   highp   mat4 	matWorldViewProj;
uniform   highp   mat4 	matWorldView;

uniform   mediump   vec4  g_f4Fog;
uniform   lowp	    vec4  g_f4FogCol;
uniform   mediump   vec4  g_f4Light0Pos;
uniform   lowp   	vec4  g_f4Light0Col;
uniform   mediump   vec4  g_f4Light1Pos;
uniform   lowp   	vec4  g_f4Light1Col;
uniform   lowp      vec4  g_f4Ambient;
uniform   lowp      vec4  g_f4MaterialDiffuse;
uniform   lowp      vec4  g_f4MaterialSpecular;

void main()
{
    gl_Position = vec4(inPos,1) * matWorldViewProj;

    mediump vec3 f3ViewPos     = (vec4(inPos,1)*matWorldView).xyz;	
	mediump vec3 f3Normal	   = (inNorm*2.0) - 1.0;
    mediump vec3 f3ViewN       = (f3Normal*mat3(matWorldView[0].xyz,matWorldView[1].xyz,matWorldView[2].xyz));	
  
   	// Light 0
	// -------------------------------------
	mediump vec3  f3L			= normalize(g_f4Light0Pos.xyz - f3ViewPos);	
	mediump float fNDotL		= max( 0.0, dot ( f3ViewN, f3L ));	
	mediump vec3  fH			= normalize(f3L - normalize(f3ViewPos));
	mediump float fSpec			= max( 0.0, pow( dot( fH, f3ViewN ), 3.0 ));		
	lowp 	vec4  fLight0		= (fNDotL*g_f4Light0Col*g_f4MaterialDiffuse);
	lowp    vec4  fSpec0 		= (fSpec*g_f4MaterialSpecular);
	
    // Light 1 - Cheapo-light for the player boost glow. Just intensity based on dist from player!
	// -------------------------------------
	fLight0.rgb = fLight0.rgb + max( 0.0, (g_f4Light1Pos.a - length( f3ViewPos - g_f4Light1Pos.xyz )) / g_f4Light1Pos.a) * g_f4Light1Col.rgb * g_f4MaterialDiffuse.rgb; 	

	lowp	vec4  f4Col			= inCol * (g_f4Ambient + fLight0 + fSpec0 );
   
   
   	// Fog+AlphaFade
	// -------------------------------------	
   	mediump float fFog          = min(1.0, 1.0 - min(1.0, (f3ViewPos.z - g_f4Fog.x)*g_f4Fog.y));
	mediump float fAlpha        = min(1.0, 1.0 - min(1.0, (f3ViewPos.z - g_f4Fog.z)*g_f4Fog.w));
	outCol.rgb	 		 		= mix( g_f4FogCol.rgb, f4Col.rgb, fFog );			
	outCol.a     		 		= inCol.a * fAlpha;
   
    outUV = inUV / 256.0;
}

[FragmentShader]
uniform lowp	sampler2D texture0;
varying mediump	vec4 	  outCol;
varying lowp    vec2 	  outUV;

void main()
{ 
  gl_FragColor.rgba =  texture2D(texture0, outUV.xy ).rgba * outCol.rgba;  
}
