
//
// LitFogged3D - Textured and vertex coloured
//

[VertexShader]

attribute highp   vec3 	inPos;
attribute mediump vec2 	inUV;	 
attribute lowp    vec4 	inCol;	 
attribute mediump vec3 	inNorm;

varying   lowp	  vec4 	outCol;
varying   lowp    vec2 	outUV;	 
uniform   highp   mat4 	matWorldViewProj;
uniform   highp   mat4 	matWorldView;

uniform   mediump   vec4  g_f4Fog;
uniform   mediump   vec4  g_f4FogCol;
uniform   mediump   vec4  g_f4Light0Pos;
uniform   lowp   	vec4  g_f4Light0Col;
uniform   mediump   vec4  g_f4Light1Pos;
uniform   lowp   	vec4  g_f4Light1Col;
uniform   lowp      vec4  g_f4Ambient;
uniform   lowp      vec4  g_f4MaterialDiffuse;
uniform   lowp      vec4  g_f4MaterialSpecular;

void main()
{
    gl_Position = vec4(inPos,1) * matWorldViewProj;

    mediump vec3 f3ViewPos     = (vec4(inPos,1)*matWorldView).xyz;	
	mediump vec3 f3Normal	   = (inNorm*2.0) - 1.0;
    mediump vec3 f3ViewN       = (f3Normal*mat3(matWorldView[0].xyz,matWorldView[1].xyz,matWorldView[2].xyz));	
  
   	// Fade out based on normal
	// -------------------------------------
	mediump float fA			= f3ViewN.z*f3ViewN.z;
   
   	// Fog+AlphaFade
	// -------------------------------------	
	mediump float fAlpha        = min(1.0, 1.0 - min(1.0, (f3ViewPos.z - g_f4Fog.z)*g_f4Fog.w));
	outCol.rgb	 		 		= inCol.rgb;			
	outCol.a     		 		= fA*inCol.a * fAlpha;
	outCol.rgba 			   *= g_f4MaterialDiffuse;
	
    outUV = inUV / 256.0;
}

[FragmentShader]
uniform sampler2D 		texture0;
varying lowp	vec4 	outCol;
varying lowp    vec2 	outUV;

void main()
{ 
  gl_FragColor.rgba =  texture2D(texture0, outUV.xy ).rgba * outCol.rgba;  
}
