
//
// ProjShadow3D - Projected shadow blobs
//

[VertexShader]

attribute highp   vec3 	inPos;
attribute mediump vec2 	inUV;	 
attribute lowp    vec4 	inCol;	 
attribute mediump vec3 	inNorm;

varying   lowp    vec4 	outCol;
varying   mediump vec2 	outUV;	 
uniform   highp   mat4 	matWorldViewProj;
uniform   highp   mat4 	matWorldView;
uniform   highp   mat4 	g_f4x4TexProj;
uniform   mediump vec4  vecUserParam;
uniform   mediump vec4  g_f4Fog;
uniform   mediump vec4  g_f4FogCol;

void main()
{
	mediump vec4  f4Pos = vec4(inPos,1);
    
	gl_Position = f4Pos * matWorldViewProj;
    mediump vec3 f3ViewPos     = (f4Pos*matWorldView).xyz;	
	mediump vec3 f3Normal	   = (inNorm*2.0) - 1.0;

	
	// Fade out based on distance and normal
	// -------------------------------------	
	lowp	vec4 f4Col			= inCol;
	float fAlphaScale    = 1.5 * dot( vecUserParam.xyz, f3Normal ) - 0.2;		
	fAlphaScale			 = max( 0.0, min( fAlphaScale, 1.0 ) );		
	float fDistScale     = 1.0 + (0.15*dot( f4Pos.xyzw, vecUserParam.xyzw ));
	fAlphaScale			 = max( 0.0, min( fAlphaScale*fDistScale, 1.0 ) );		
   
   	// Fog+AlphaFade
	// -------------------------------------	   	
	mediump float fAlpha        = 1.0 - min(1.0, (f3ViewPos.z - g_f4Fog.z)*g_f4Fog.w);
	outCol.rgb	 		 		= f4Col.rgb * fAlpha;
	outCol.a     		 		= f4Col.a * min( 1.0 , fAlpha*fAlphaScale );
   
	// Projected UVs
	// -------------------------------------   
    outUV = (f4Pos * g_f4x4TexProj).xy;
}

[FragmentShader]
uniform sampler2D 		texture0;
varying lowp    vec4 	outCol;
varying mediump vec2 	outUV;

void main()
{ 
  gl_FragColor.rgba =  texture2D(texture0, outUV.xy ).rgba * outCol.rgba;  
}
